@@ -1,9 +1,10 @@
 import os
 import posixpath
 import mimetypes
+from datetime import datetime
 from gzip import GzipFile
-import datetime
 from tempfile import SpooledTemporaryFile
+import warnings
 
 from django.core.files.base import File
 from django.core.files.storage import Storage
@@ -15,7 +16,7 @@ try:
     from boto.s3.connection import S3Connection, SubdomainCallingFormat
     from boto.exception import S3ResponseError
     from boto.s3.key import Key as S3Key
-    from boto.utils import parse_ts
+    from boto.utils import parse_ts, ISO8601
 except ImportError:
     raise ImproperlyConfigured("Could not load Boto's S3 bindings.\n"
                                "See https://github.com/boto/boto")
@@ -31,13 +32,12 @@ if boto_version_info[:2] < (2, 32):
 
 
 def parse_ts_extended(ts):
-    RFC1123 = '%a, %d %b %Y %H:%M:%S %Z'
-    rv = None
-    try:
-        rv = parse_ts(ts)
-    except ValueError:
-        rv = datetime.datetime.strptime(ts, RFC1123)
-    return rv
+    warnings.warn(
+        "parse_ts_extended has been deprecated and will be removed in version "
+        "1.3 because boto.utils.parse_ts has subsumed the old functionality.",
+        PendingDeprecationWarning
+    )
+    return parse_ts(ts)
 
 
 def safe_join(base, *paths):
@@ -411,6 +411,7 @@ class S3BotoStorage(Storage):
             key = self.bucket.new_key(encoded_name)
         if self.preload_metadata:
             self._entries[encoded_name] = key
+            key.last_modified = datetime.utcnow().strftime(ISO8601)
 
         key.set_metadata('Content-Type', content_type)
         self._save_content(key, content, headers=headers)
@@ -476,7 +477,7 @@ class S3BotoStorage(Storage):
         if entry is None:
             entry = self.bucket.get_key(self._encode_name(name))
         # Parse the last_modified string to a local datetime object.
-        return parse_ts_extended(entry.last_modified)
+        return parse_ts(entry.last_modified)
 
     def url(self, name, headers=None, response_headers=None):
         # Preserve the trailing slash after normalizing the path.
